Version 0.1 (August 23, 2022)

- Includes support for MyST and sphinx-gallery

Version 0.1.6 (October 9, 2022)

- Added page title and header as a parameter
- Alphabetic sorting of tags
- Added removal of all .md and .rst files in the tag folder before generating them again (avoids having duplicates after removing/changing some tag)
- Tag intro text as a parameter
